Crate actix_proxy_protocol

Crate actix_proxy_protocol 

Actix networking integration for the PROXY protocol.

Modules

tlv
Type-length-value support for PROXY protocol v2 headers.
v1
PROXY protocol v1 header support.
v2
PROXY protocol v2 header parsing and serialization.

Structs

Acceptor
Actix service factory that wraps accepted streams in ProxyStream.
AcceptorService
Actix service that wraps streams in ProxyStream.
ParseError
PROXY protocol parse error.
ProxyStream
Stream wrapper that consumes a leading PROXY protocol header and then behaves like IO.

Enums

AddressFamily
Address Family.
Command
Command
Header
Parsed PROXY protocol header.
HeaderPolicy
Controls whether incoming streams must start with a PROXY protocol header.
ProxyProtocolError
PROXY protocol acceptor or stream parsing error.
TransportProtocol
Transport Protocol.
Version
PROXY Protocol Version.