pub enum HeaderPolicy {
Required,
Optional,
}Expand description
Controls whether incoming streams must start with a PROXY protocol header.
Variants
Required
Reject streams that do not start with a PROXY protocol header.
Optional
Accept streams without a PROXY protocol header and replay any bytes read during detection.