Module tlv

Module tlv 

Type-length-value support for PROXY protocol v2 headers.

Structs

Alpn
Application-Layer Protocol Negotiation (ALPN).
Authority
The host name value passed by the client, as a UTF-8-encoded string.
Crc32c
A 32-bit number storing the CRC32c checksum of the PROXY protocol header.
NetNamespace
Network namespace name.
Noop
A no-op TLV.
Ssl
TLS (SSL) details.
SslClientFlags
SSL/TLS client flags carried by an SSL TLV.
UniqueId
An opaque byte sequence of up to 128 bytes generated by the upstream proxy that uniquely identifies the connection.

Enums

SslSubTlv
Nested SSL TLV.

Traits

Tlv
PROXY protocol v2 type-length-value extension.