Authority

Struct Authority 

pub struct Authority { /* private fields */ }
The host name value passed by the client, as a UTF-8-encoded string.

In case of TLS being used on the client connection, this is the exact copy of the “server_name” extension as defined by RFC 3546, section 3.1, often referred to as “SNI”. There are probably other situations where an authority can be mentioned on a connection without TLS being involved at all.

Implementations

Source

impl Authority

pub fn new(authority: impl Into<String>) -> Authority

Constructs a new authority TLV from a UTF-8 string.

Panics

Panics if authority is an empty string.

pub fn as_str(&self) -> &str

Returns the authority string.