pub struct SslClientFlags(/* private fields */);Expand description
SSL/TLS client flags carried by an SSL TLV.
Implementations
Sourceimpl SslClientFlags
impl SslClientFlags
Sourcepub const SSL: SslClientFlags
pub const SSL: SslClientFlags
Client connected over SSL/TLS.
Sourcepub const CERT_CONN: SslClientFlags
pub const CERT_CONN: SslClientFlags
Client provided a certificate on the current connection.
Sourcepub const CERT_SESS: SslClientFlags
pub const CERT_SESS: SslClientFlags
Client provided a certificate at least once over this TLS session.
Sourceimpl SslClientFlags
impl SslClientFlags
Sourcepub const fn empty() -> SslClientFlags
pub const fn empty() -> SslClientFlags
Get a flags value with all bits unset.
Sourcepub const fn all() -> SslClientFlags
pub const fn all() -> SslClientFlags
Get a flags value with all known bits set.
Sourcepub const fn bits(&self) -> u8
pub const fn bits(&self) -> u8
Get the underlying bits value.
The returned value is exactly the bits set in this flags value.
Sourcepub const fn from_bits(bits: u8) -> Option<SslClientFlags>
pub const fn from_bits(bits: u8) -> Option<SslClientFlags>
Convert from a bits value.
This method will return None if any unknown bits are set.
Sourcepub const fn from_bits_truncate(bits: u8) -> SslClientFlags
pub const fn from_bits_truncate(bits: u8) -> SslClientFlags
Convert from a bits value, unsetting any unknown bits.
Sourcepub const fn from_bits_retain(bits: u8) -> SslClientFlags
pub const fn from_bits_retain(bits: u8) -> SslClientFlags
Convert from a bits value exactly.
Sourcepub fn from_name(name: &str) -> Option<SslClientFlags>
pub fn from_name(name: &str) -> Option<SslClientFlags>
Get a flags value with the bits of a flag with the given name set.
This method will return None if name is empty or doesn’t
correspond to any named flag.
Sourcepub const fn intersects(&self, other: SslClientFlags) -> bool
pub const fn intersects(&self, other: SslClientFlags) -> bool
Whether any set bits in other are also set in self.
Sourcepub const fn contains(&self, other: SslClientFlags) -> bool
pub const fn contains(&self, other: SslClientFlags) -> bool
Whether all set bits in other are also set in self.
Sourcepub fn insert(&mut self, other: SslClientFlags)
pub fn insert(&mut self, other: SslClientFlags)
The bitwise or (|) of the bits in self and other.
Sourcepub fn remove(&mut self, other: SslClientFlags)
pub fn remove(&mut self, other: SslClientFlags)
The intersection of self with the complement of other (&!).
This method is not equivalent to self & !other when other has unknown bits set.
remove won’t truncate other, but the ! operator will.
Sourcepub fn toggle(&mut self, other: SslClientFlags)
pub fn toggle(&mut self, other: SslClientFlags)
The bitwise exclusive-or (^) of the bits in self and other.
Sourcepub fn set(&mut self, other: SslClientFlags, value: bool)
pub fn set(&mut self, other: SslClientFlags, value: bool)
Call insert when value is true or remove when value is false.
Sourcepub const fn intersection(self, other: SslClientFlags) -> SslClientFlags
pub const fn intersection(self, other: SslClientFlags) -> SslClientFlags
The bitwise and (&) of the bits in self and other.
Sourcepub const fn union(self, other: SslClientFlags) -> SslClientFlags
pub const fn union(self, other: SslClientFlags) -> SslClientFlags
The bitwise or (|) of the bits in self and other.
Sourcepub const fn difference(self, other: SslClientFlags) -> SslClientFlags
pub const fn difference(self, other: SslClientFlags) -> SslClientFlags
The intersection of self with the complement of other (&!).
This method is not equivalent to self & !other when other has unknown bits set.
difference won’t truncate other, but the ! operator will.
Sourcepub const fn symmetric_difference(self, other: SslClientFlags) -> SslClientFlags
pub const fn symmetric_difference(self, other: SslClientFlags) -> SslClientFlags
The bitwise exclusive-or (^) of the bits in self and other.
Sourcepub const fn complement(self) -> SslClientFlags
pub const fn complement(self) -> SslClientFlags
The bitwise negation (!) of the bits in self, truncating the result.
Sourceimpl SslClientFlags
impl SslClientFlags
Sourcepub const fn iter(&self) -> Iter<SslClientFlags> ⓘ
pub const fn iter(&self) -> Iter<SslClientFlags> ⓘ
Yield a set of contained flags values.
Each yielded flags value will correspond to a defined named flag. Any unknown bits will be yielded together as a final flags value.
Sourcepub const fn iter_names(&self) -> IterNames<SslClientFlags> ⓘ
pub const fn iter_names(&self) -> IterNames<SslClientFlags> ⓘ
Yield a set of contained named flags values.
This method is like iter, except only yields bits in contained named flags.
Any unknown bits, or bits not corresponding to a contained flag will not be yielded.