UniqueId

Struct UniqueId 

pub struct UniqueId { /* private fields */ }
An opaque byte sequence of up to 128 bytes generated by the upstream proxy that uniquely identifies the connection.

The unique ID can be used to easily correlate connections across multiple layers of proxies, without needing to look up IP addresses and port numbers.

Implementations

Source

impl UniqueId

pub fn new(id: impl Into<Vec<u8>>) -> UniqueId

Constructs a new unique ID TLV.

Panics

Panics if value is 0 bytes or larger than 128 bytes.

pub fn as_bytes(&self) -> &[u8]

Returns the unique ID bytes.