pub enum AddressFamily {
Unspecified,
Inet,
Inet6,
Unix,
}Expand description
Address Family.
maps to the original socket family without necessarily matching the values internally used by the system.
other values are unspecified and must not be emitted in version 2 of this protocol and must be rejected as invalid by receivers.
Variants
Unspecified
0x0 : AF_UNSPEC : the connection is forwarded for an unknown, unspecified or unsupported protocol. The sender should use this family when sending LOCAL commands or when dealing with unsupported protocol families. The receiver is free to accept the connection anyway and use the real endpoint addresses or to reject it. The receiver should ignore address information.
Inet
0x1 : AF_INET : the forwarded connection uses the AF_INET address family (IPv4). The addresses are exactly 4 bytes each in network byte order, followed by transport protocol information (typically ports).
Inet6
0x2 : AF_INET6 : the forwarded connection uses the AF_INET6 address family (IPv6). The addresses are exactly 16 bytes each in network byte order, followed by transport protocol information (typically ports).
Unix
0x3 : AF_UNIX : the forwarded connection uses the AF_UNIX address family (UNIX). The addresses are exactly 108 bytes each.